@@ -24,7 +24,7 @@
 #include "bakery/bakery.h"
 #include "frame_glom.h"
 
-#include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
+#include <libglom/libglom_config.h> // For GLOM_ENABLE_CLIENT_ONLY
 
 
 //Avoid including the header here:
@@ -82,8 +82,8 @@ public:
   void set_show_sql_debug(bool val = true);
 
   static App_Glom* get_application();
-	
-protected:
+
+private:
   virtual void init_layout(); //override.
   virtual void init_menus_file(); //override.
   virtual void init_menus(); //override.
@@ -99,15 +99,18 @@ protected:
   void on_menu_help_contents();
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   void existing_or_new_new();
-	
+
   void on_menu_userlevel_developer();
   void on_menu_userlevel_operator();
   void on_menu_file_save_as_example();
   void on_menu_developer_changelanguage();
   void on_menu_developer_translations();
-  void on_window_translations_hide();
+  void on_menu_developer_active_platform_normal();
+  void on_menu_developer_active_platform_maemo();
   void on_menu_developer_show_layout_toolbar();
 
+  void on_window_translations_hide();
+
   virtual Glib::ustring ui_file_select_save(const Glib::ustring& old_file_uri); //overridden.
   void on_userlevel_changed(AppState::userlevels userlevel);
 
@@ -147,7 +150,9 @@ protected:
   type_listActions m_listDeveloperActions; //Only enabled when in developer mode.
   Glib::RefPtr<Gtk::Action> m_action_mode_data, m_action_mode_find;
 #ifndef GLOM_ENABLE_CLIENT_ONLY
+  Glib::RefPtr<Gtk::Action> m_action_developer_users;
   Glib::RefPtr<Gtk::RadioAction> m_action_menu_userlevel_developer, m_action_menu_userlevel_operator;
+  Glib::RefPtr<Gtk::ToggleAction> m_action_show_layout_toolbar;
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
   Gtk::VBox* m_pBoxTop;
@@ -171,7 +176,7 @@ protected:
 
   Glib::ustring m_ui_save_extra_newdb_title;
 
-  bool m_ui_save_extra_newdb_selfhosted;
+  Document_Glom::HostingMode m_ui_save_extra_newdb_hosting_mode;
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
   // This is set to the URI of an example file that is loaded to be able to
@@ -183,7 +188,7 @@ protected:
   //we already asked for them when getting the document over the network,
   //so we can use them again when connecting directly to the database:
   Glib::ustring m_temp_username, m_temp_password;
-	
+
   bool m_show_sql_debug;
 };
 
