@@ -18,10 +18,11 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "config.h"
+#include <libglom/libglom_config.h>
 #include "dialog_existing_or_new.h"
 
 #include <libxml++/parsers/saxparser.h>
+#include <libxml/parser.h> //For xmlStopParser()
 
 #include <glibmm/i18n.h>
 #include <giomm/contenttype.h>
@@ -48,14 +49,8 @@ const char* RECENT_DUMMY_TEXT = N_("No recently used documents available.");
 const char* TEMPLATE_DUMMY_TEXT = N_("No templates available.");
 const char* NETWORK_DUMMY_TEXT = N_("No sessions found on the local network.");
 
-/*bool has_dummy(const Gtk::TreeModel::iterator& parent, const std::auto_ptr<Gtk::TreeModel::iterator>& dummy)
-{
-  if(dummy.get() == NULL) return false;
-  const Gtk::TreeNodeChildren& children = parent->children();
-  return children.begin() == *dummy;
-}*/
-
-// Reads the title of an example from the first few characters of the XML
+//TODO_Performance: A DomParser or XmlReader might be faster, or even a regex.
+/// Reads the title of an example from the first few characters of the XML.
 class Parser: public xmlpp::SaxParser
 {
 public:
@@ -68,22 +63,22 @@ public:
     return m_title;
   }
 
-protected:
+private:
   virtual void on_start_element(const Glib::ustring& name, const AttributeList& attributes)
   {
     if(m_title.empty()) // Already found name? Wait for parse_chunk() call to return.
     {
-      if(name == "glom_document")
+      if(name == "glom_document") //See document_glom.cc for the #defines.
       {
         for(AttributeList::const_iterator iter = attributes.begin(); iter != attributes.end(); ++ iter)
         {
           if(iter->name == "database_title")
           {
             m_title = iter->value;
-            // TODO: We should stop parsing here somehow, but I don't
-            // think we can throw an exception through the C library back
-            // to get_example_name, and there does not seem to be API to
-            // stop parsing.
+
+            // Stop parsing here because we have what we need:
+            xmlStopParser(context_);
+
             break;
           }
         }
@@ -94,7 +89,7 @@ protected:
   Glib::ustring m_title;
 };
 
-}
+} //anonymous namespace
 
 namespace Glom
 {
@@ -162,8 +157,8 @@ Dialog_ExistingOrNew::Dialog_ExistingOrNew(BaseObjectType* cobject, const Glib::
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 
 #ifdef G_OS_WIN32
-  gchar* dir = g_win32_get_package_installation_subdirectory(NULL, NULL, "share/glom/doc/examples");
-  std::string path(dir);
+  gchar* dir = g_win32_get_package_installation_directory_of_module(NULL);
+  std::string path = Glib::build_filename(dir, "share/glom/doc/examples");
   g_free(dir);
 
   if(!Glib::file_test(path, Glib::FILE_TEST_EXISTS))
@@ -298,7 +293,7 @@ Dialog_ExistingOrNew::~Dialog_ExistingOrNew()
   }
 }
 
-bool Dialog_ExistingOrNew::on_existing_select_func(const Glib::RefPtr<Gtk::TreeModel>& model, const Gtk::TreeModel::Path& path, bool path_currently_selected)
+bool Dialog_ExistingOrNew::on_existing_select_func(const Glib::RefPtr<Gtk::TreeModel>& model, const Gtk::TreeModel::Path& path, bool /* path_currently_selected */)
 {
   Gtk::TreeModel::iterator iter = model->get_iter(path);
 #ifndef G_OS_WIN32
@@ -311,7 +306,7 @@ bool Dialog_ExistingOrNew::on_existing_select_func(const Glib::RefPtr<Gtk::TreeM
   return true;
 }
 
-bool Dialog_ExistingOrNew::on_new_select_func(const Glib::RefPtr<Gtk::TreeModel>& model, const Gtk::TreeModel::Path& path, bool path_currently_selected)
+bool Dialog_ExistingOrNew::on_new_select_func(const Glib::RefPtr<Gtk::TreeModel>& model, const Gtk::TreeModel::Path& path, bool /* path_currently_selected */)
 {
   Gtk::TreeModel::iterator iter = model->get_iter(path);
   if(iter == m_iter_new_template)
@@ -536,7 +531,7 @@ void Dialog_ExistingOrNew::new_title_data_func(Gtk::CellRenderer* renderer, cons
   }
 }
 
-void Dialog_ExistingOrNew::on_switch_page(GtkNotebookPage* page, guint page_num)
+void Dialog_ExistingOrNew::on_switch_page(GtkNotebookPage* /* page */, guint /* page_num */)
 {
   update_ui_sensitivity();
 }
@@ -723,6 +718,16 @@ void Dialog_ExistingOrNew::on_stream_read(const Glib::RefPtr<Gio::AsyncResult>&
 #endif /* !GLOM_ENABLE_CLIENT_ONLY */
 
 #ifndef G_OS_WIN32
+void Dialog_ExistingOrNew::on_service_found_static(EpcServiceMonitor* /* monitor */, gchar* name, EpcServiceInfo* info, gpointer user_data)
+{
+  static_cast<Dialog_ExistingOrNew*>(user_data)->on_service_found(name, info);
+}
+
+void Dialog_ExistingOrNew::on_service_removed_static(EpcServiceMonitor* /* monitor */, gchar* name, gchar* type, gpointer user_data)
+{
+  static_cast<Dialog_ExistingOrNew*>(user_data)->on_service_removed(name, type);
+}
+
 void Dialog_ExistingOrNew::on_service_found(const Glib::ustring& name, EpcServiceInfo* info)
 {
   //Translator hint: This is <Service Name> on <Host> (via Network Interface such as eth0).
@@ -744,7 +749,7 @@ void Dialog_ExistingOrNew::on_service_found(const Glib::ustring& name, EpcServic
   }
 }
 
-void Dialog_ExistingOrNew::on_service_removed(const Glib::ustring& name, const Glib::ustring& type)
+void Dialog_ExistingOrNew::on_service_removed(const Glib::ustring& name, const Glib::ustring& /* type */)
 {
   // Find the entry with the given name
   const Gtk::TreeNodeChildren& children = m_iter_existing_network->children();
@@ -766,7 +771,7 @@ void Dialog_ExistingOrNew::on_service_removed(const Glib::ustring& name, const G
 }
 #endif // !G_OS_WIN32
 
-void Dialog_ExistingOrNew::on_existing_row_activated(const Gtk::TreeModel::Path& path, Gtk::TreeViewColumn* column)
+void Dialog_ExistingOrNew::on_existing_row_activated(const Gtk::TreeModel::Path& /* path */, Gtk::TreeViewColumn* /* column */)
 {
   if(m_select_button->is_sensitive())
     on_select_clicked();
@@ -780,7 +785,7 @@ void Dialog_ExistingOrNew::on_existing_button_clicked(const Gtk::TreeModel::Path
     on_select_clicked();
 }
 
-void Dialog_ExistingOrNew::on_new_row_activated(const Gtk::TreeModel::Path& path, Gtk::TreeViewColumn* column)
+void Dialog_ExistingOrNew::on_new_row_activated(const Gtk::TreeModel::Path& /* path */, Gtk::TreeViewColumn* /* column */)
 {
   if(m_select_button->is_sensitive())
     on_select_clicked();
@@ -823,4 +828,5 @@ void Dialog_ExistingOrNew::on_select_clicked()
   }
 }
 
+
 } //namespace Glom
