@@ -19,9 +19,9 @@
  */
 
 #include "dialog_import_csv_progress.h"
-#include "config.h"
+#include <libglom/libglom_config.h>
 
-#include <glom/libglom/data_structure/glomconversions.h>
+#include <libglom/data_structure/glomconversions.h>
 #include <glibmm/i18n.h>
 
 namespace Glom
@@ -148,7 +148,7 @@ bool Dialog_Import_CSV_Progress::on_idle_import()
       // we export it this way.
       // TODO: Document what that format is.
       bool success = false;
-      Gnome::Gda::Value value = field->from_sql(m_data_source->get_data(m_current_row, i), Field::SQL_FORMAT_POSTGRES, success);
+      Gnome::Gda::Value value = field->from_file_format(m_data_source->get_data(m_current_row, i), success);
 
       if(success)
       {
@@ -211,7 +211,7 @@ bool Dialog_Import_CSV_Progress::on_idle_import()
   return true;
 }
 
-void Dialog_Import_CSV_Progress::on_response(int response_id)
+void Dialog_Import_CSV_Progress::on_response(int /* response_id */)
 {
   // Don't continue importing when the user already cancelled, or closed the
   // window via delete event.
@@ -249,13 +249,13 @@ Gnome::Gda::Value Dialog_Import_CSV_Progress::get_primary_key_value_selected() c
 // These don't make sense in Dialog_Import_CSV_Progress, and thus should not
 // be called. We need to implement them though, because they are pure abstract
 // in Base_DB_Table_Data.
-void Dialog_Import_CSV_Progress::set_primary_key_value(const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& value)
+void Dialog_Import_CSV_Progress::set_primary_key_value(const Gtk::TreeModel::iterator& /* row */, const Gnome::Gda::Value& /* value */)
 {
   // This is actually called by Base_DB_Table_Data::record_new(), but we can safely ignore it.
   //throw std::logic_error("Dialog_Import_CSV_Progress::set_primary_key_value() called");
 }
 
-Gnome::Gda::Value Dialog_Import_CSV_Progress::get_primary_key_value(const Gtk::TreeModel::iterator& row) const
+Gnome::Gda::Value Dialog_Import_CSV_Progress::get_primary_key_value(const Gtk::TreeModel::iterator& /* row */) const
 {
   throw std::logic_error("Dialog_Import_CSV_Progress::get_primary_key_value() called");
 }
