@@ -19,7 +19,8 @@
  */
 
 #include "dialog_field_layout.h"
-#include <glom/libglom/data_structure/glomconversions.h>
+#include <libglom/data_structure/glomconversions.h>
+#include <libglom/glade_utils.h>
 #include <glibmm/i18n.h>
 
 namespace Glom
@@ -53,7 +54,7 @@ Dialog_FieldLayout::Dialog_FieldLayout(BaseObjectType* cobject, const Glib::RefP
   //Get the formatting stuff:
   try
   {
-    Glib::RefPtr<Gnome::Glade::Xml> refXmlFormatting = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "box_formatting");
+    Glib::RefPtr<Gnome::Glade::Xml> refXmlFormatting = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "box_formatting");
     refXmlFormatting->get_widget_derived("box_formatting", m_box_formatting);
   }
   catch(const Gnome::Glade::XmlError& ex)
@@ -76,10 +77,8 @@ Dialog_FieldLayout::~Dialog_FieldLayout()
 
 void Dialog_FieldLayout::set_field(const sharedptr<const LayoutItem_Field>& field, const Glib::ustring& table_name)
 {
-  if(!field)
-    return;
-
   m_layout_item = glom_sharedptr_clone(field);
+
   m_table_name = table_name;
 
   m_label_field_name->set_text( field->get_layout_display_name() );
@@ -109,6 +108,12 @@ void Dialog_FieldLayout::set_field(const sharedptr<const LayoutItem_Field>& fiel
 
 sharedptr<LayoutItem_Field> Dialog_FieldLayout::get_field_chosen() const
 {
+    double x = 0;
+    double y = 0;
+    double width, height;
+    m_layout_item->get_print_layout_position(x, y, width, height);
+    std::cout << "DEBUGDialog_FieldLayout::get_field_chosen1(): m_layout_item: x=" << x << std::endl;
+
   m_layout_item->set_editable( m_checkbutton_editable->get_active() );
 
   m_layout_item->set_formatting_use_default( !m_radiobutton_custom_formatting->get_active() );
@@ -120,6 +125,14 @@ sharedptr<LayoutItem_Field> Dialog_FieldLayout::get_field_chosen() const
 
   m_layout_item->set_title_custom(title_custom);
 
+  {
+    double x = 0;
+    double y = 0;
+    double width, height;
+    m_layout_item->get_print_layout_position(x, y, width, height);
+    std::cout << "DEBUGDialog_FieldLayout::get_field_chosen2(): m_layout_item: x=" << x << std::endl;
+  }
+
   return glom_sharedptr_clone(m_layout_item);
 }
 
