@@ -23,7 +23,7 @@
 
 #include "../base_db.h"
 #include "../mode_data/dialog_layout.h"
-#include <glom/libglom/data_structure/layout/layoutitem_notebook.h>
+#include <libglom/data_structure/layout/layoutitem_notebook.h>
 #include <libglademm.h>
 
 namespace Glom
@@ -40,7 +40,7 @@ public:
   void set_notebook(const sharedptr<const LayoutItem_Notebook>& start_notebook);
   sharedptr<LayoutItem_Notebook> get_notebook() const;
 
-protected:
+private:
 
   //Enable/disable buttons, depending on treeview selection:
   virtual void enable_buttons();
