@@ -18,17 +18,24 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "config.h" // For GLOM_ENABLE_MAEMO
+#include <libglom/libglom_config.h> // For GLOM_ENABLE_MAEMO
  
-#include <glom/libglom/connectionpool.h>
-#include <glom/libglom/document/document_glom.h>
+#include <libglom/connectionpool.h>
+#include <libglom/document/document_glom.h>
 #include <bakery/bakery.h>
 //#include <libgdamm/connectionevent.h>
 #include <glibmm/i18n.h>
 
 #ifndef G_OS_WIN32
-#include <libepc/shell.h> //For epc_shell_set_progress_hooks().
-#include <libepc/publisher.h>
+# include <libepc/shell.h> //For epc_shell_set_progress_hooks().
+# include <libepc/publisher.h>
+#else
+// objidl.h, included by windows.h, defines a type called DATADIR, so we need
+// to undef it temporarily.
+# define GLOM_SAVE_DATADIR DATADIR
+# undef DATADIR
+# include <windows.h>
+# define DATADIR GLOM_SAVE_DATADIR
 #endif
 
 #ifdef GLOM_ENABLE_MAEMO
@@ -37,11 +44,11 @@
 
 #include <signal.h> //To catch segfaults
 
-/* TODO: Should this be used in client-only mode? */
-
+#ifndef GLOM_ENABLE_CLIENT_ONLY
 #ifndef G_OS_WIN32
 static EpcProtocol publish_protocol = EPC_PROTOCOL_HTTPS;
 #endif
+#endif
 
 // Uncomment to see debug messages
 //#define GLOM_CONNECTION_DEBUG
@@ -158,25 +165,6 @@ pgwin32_is_admin(void)
 namespace Glom
 {
 
-ExceptionConnection::ExceptionConnection(failure_type failure)
-: m_failure_type(failure)
-{
-}
-
-ExceptionConnection::~ExceptionConnection() throw()
-{
-}
-
-const char* ExceptionConnection::what() const throw()
-{
-  return "Glom database connection failed.";
-}
-
-ExceptionConnection::failure_type ExceptionConnection::get_failure_type() const
-{
-  return m_failure_type;
-}
-
 SharedConnection::SharedConnection()
 {
 }
@@ -219,229 +207,6 @@ void SharedConnection::close()
   m_signal_finished.emit();
 }
 
-
-
-bool ConnectionPoolBackend::initialize(Gtk::Window* /* parent_window */, const Glib::ustring& /* initial_username */, const Glib::ustring& /* password */)
-{
-  return true;
-}
-
-bool ConnectionPoolBackend::startup(Gtk::Window* /* parent_window */)
-{
-  return true;
-}
-
-void ConnectionPoolBackend::cleanup(Gtk::Window* /* parent_window */)
-{}
-
-bool ConnectionPoolBackend::set_server_operation_value(const Glib::RefPtr<Gnome::Gda::ServerOperation>& operation, const Glib::ustring& path, const Glib::ustring& value, std::auto_ptr<Glib::Error>& error)
-{
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-  try
-  {
-    operation->set_value_at(path, value);
-    return true;
-  }
-  catch(const Glib::Error& ex)
-  {
-    error.reset(new Glib::Error(ex));
-    return false;
-  }
-#else
-  operation->set_value_at(path, value, error);
-  if(error.get()) return false;
-  return true;
-#endif
-}
-
-Glib::RefPtr<Gnome::Gda::ServerOperation> ConnectionPoolBackend::create_server_operation(const Glib::RefPtr<Gnome::Gda::ServerProvider>& provider, const Glib::RefPtr<Gnome::Gda::Connection>& connection, Gnome::Gda::ServerOperationType type, std::auto_ptr<Glib::Error>& error)
-{
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-  try
-  {
-    return provider->create_operation(connection, type);
-  }
-  catch(const Glib::Error& ex)
-  {
-    error.reset(new Glib::Error(ex));
-    return Glib::RefPtr<Gnome::Gda::ServerOperation>();
-  }
-#else
-  return provider->create_operation(connection, type, error);
-#endif
-}
-
-bool ConnectionPoolBackend::perform_server_operation(const Glib::RefPtr<Gnome::Gda::ServerProvider>& provider, const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::RefPtr<Gnome::Gda::ServerOperation>& operation, std::auto_ptr<Glib::Error>& error)
-{
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-  try
-  {
-    provider->perform_operation(connection, operation);
-    return true;
-  }
-  catch(const Glib::Error& ex)
-  {
-    error.reset(new Glib::Error(ex));
-    return false;
-  }
-#else
-  provider->perform_operation(connection, operation, error);
-  if(error.get()) return false;
-  return true;
-#endif
-}
-
-bool ConnectionPoolBackend::begin_transaction(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& name, Gnome::Gda::TransactionIsolation level, std::auto_ptr<Glib::Error>& error)
-{
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-  try
-  {
-    return connection->begin_transaction(name, level);
-  }
-  catch(const Glib::Error& ex)
-  {
-    error.reset(new Glib::Error(ex));
-    return false;
-  }
-#else
-  return connection->begin_transaction(name, level, error);
-#endif
-}
-
-bool ConnectionPoolBackend::commit_transaction(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& name, std::auto_ptr<Glib::Error>& error)
-{
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-  try
-  {
-    return connection->commit_transaction(name);
-  }
-  catch(const Glib::Error& ex)
-  {
-    error.reset(new Glib::Error(ex));
-    return false;
-  }
-#else
-  return connection->commit_transaction(name, error);
-#endif
-}
-
-bool ConnectionPoolBackend::rollback_transaction(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& name, std::auto_ptr<Glib::Error>& error)
-{
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-  try
-  {
-    return connection->rollback_transaction(name);
-  }
-  catch(const Glib::Error& ex)
-  {
-    error.reset(new Glib::Error(ex));
-    return false;
-  }
-#else
-  return connection->rollback_transaction(name, error);
-#endif
-}
-
-bool ConnectionPoolBackend::query_execute(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& sql_query, std::auto_ptr<Glib::Error>& error)
-{
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-  try
-  {
-    return connection->statement_execute_non_select(sql_query) != -1;
-  }
-  catch(const Glib::Error& ex)
-  {
-    error.reset(new Glib::Error(ex));
-    return false;
-  }
-#else
-  return connection->statement_execute_non_select(sql_query, error) != -1;
-#endif
-}
-
-#ifndef GLOM_ENABLE_CLIENT_ONLY
-bool ConnectionPoolBackend::add_column(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const sharedptr<const Field>& field, std::auto_ptr<Glib::Error>& error)
-{
-  Glib::RefPtr<Gnome::Gda::ServerProvider> provider = connection->get_provider();
-  Glib::RefPtr<Gnome::Gda::ServerOperation> operation = create_server_operation(provider, connection, Gnome::Gda::SERVER_OPERATION_ADD_COLUMN, error);
-  if(!operation) return false;
-
-  if(!set_server_operation_value(operation, "/COLUMN_DEF_P/TABLE_NAME", table_name, error)) return false;
-  if(!set_server_operation_value(operation, "/COLUMN_DEF_P/COLUMN_NAME", field->get_name(), error)) return false;
-  if(!set_server_operation_value(operation, "/COLUMN_DEF_P/COLUMN_TYPE", field->get_sql_type(), error)) return false;
-  if(!set_server_operation_value(operation, "/COLUMN_DEF_P/COLUMN_PKEY", field->get_primary_key() ? "TRUE" : "FALSE", error)) return false;
-  if(!set_server_operation_value(operation, "/COLUMN_DEF_P/COLUMN_UNIQUE", field->get_unique_key() ? "TRUE" : "FALSE", error)) return false;
-
-  if(!perform_server_operation(provider, connection, operation, error)) return false;
-  return true;
-}
-
-bool ConnectionPoolBackend::drop_column(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const Glib::ustring& field_name, std::auto_ptr<Glib::Error>& error)
-{
-  Glib::RefPtr<Gnome::Gda::ServerProvider> provider = connection->get_provider();
-  Glib::RefPtr<Gnome::Gda::ServerOperation> operation = create_server_operation(provider, connection, Gnome::Gda::SERVER_OPERATION_DROP_COLUMN, error);
-  if(!operation) return false;
-
-  if(!set_server_operation_value(operation, "/COLUMN_DESC_P/TABLE_NAME", table_name, error)) return false;
-  if(!set_server_operation_value(operation, "/COLUMN_DESC_P/COLUMN_NAME", field_name, error)) return false;
-  
-  if(!perform_server_operation(provider, connection, operation, error)) return false;
-  return true;
-}
-
-//TODO: Why/When do we need to change multiple columns instead of a single one? murrayc.
-//When changing a table's primary key, we unset the primary key for the old
-//column and set it for the new column. Using a single call to the
-//ConnectionPoolBackend for this, the backend can do all the required
-//operations at once, maybe optimizing them. For example, for SQLite we need
-//to recreate the whole table when changing columns, so we only need to do
-//this once instead of twice when changing the primary key. armin.
-bool ConnectionPoolBackend::change_columns(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const type_vecConstFields& old_fields, const type_vecConstFields& new_fields, std::auto_ptr<Glib::Error>& error)
-{
-  static const char* TRANSACTION_NAME = "glom_change_columns_transaction";
-  static const gchar* TEMP_COLUMN_NAME = "glom_temp_column"; // TODO: Find a unique name.
-
-  if(!begin_transaction(connection, TRANSACTION_NAME, Gnome::Gda::TRANSACTION_ISOLATION_UNKNOWN, error)) return false; // TODO: What does the transaction isolation do?
-
-  for(unsigned int i = 0; i < old_fields.size(); ++ i)
-  {
-    // TODO: Don't create an intermediate column if the name of the column
-    // changes anyway.
-    sharedptr<Field> temp_field = glom_sharedptr_clone(new_fields[i]);
-    temp_field->set_name(TEMP_COLUMN_NAME);
-    // The temporary column must not be a primary key, otherwise
-    // we might end up with two primary key columns temporarily, which most
-    // database systems do not allow.
-    temp_field->set_primary_key(false);
-
-    if(!add_column(connection, table_name, temp_field, error)) break;
-
-    const Glib::ustring temp_move_query = "UPDATE " + table_name + " SET " + TEMP_COLUMN_NAME + " = CAST(" + old_fields[i]->get_name() + " AS " + new_fields[i]->get_sql_type() + ")";
-    if(!query_execute(connection, temp_move_query, error)) break;
-    // TODO: If this CAST was not successful, then just go on,
-    // dropping the data in the column?
-
-    if(!drop_column(connection, table_name, old_fields[i]->get_name(), error)) return false;
-
-    if(!add_column(connection, table_name, new_fields[i], error)) break;
-
-    const Glib::ustring final_move_query = "UPDATE " + table_name + " SET " + new_fields[i]->get_name() + " = " + TEMP_COLUMN_NAME; // TODO: Do we need a cast here, even though the type matches?
-    if(!query_execute(connection, final_move_query, error)) break;
-
-    if(!drop_column(connection, table_name, TEMP_COLUMN_NAME, error)) break;
-  }
-
-  if(error.get() || !commit_transaction(connection, TRANSACTION_NAME, error))
-  {
-    std::auto_ptr<Glib::Error> rollback_error;
-    rollback_transaction(connection, TRANSACTION_NAME, rollback_error);
-    return false;
-  }
-
-  return true;
-}
-#endif // !GLOM_ENABLE_CLIENT_ONLY
-
 //init_db_details static data:
 ConnectionPool* ConnectionPool::m_instance = 0;
 
@@ -499,17 +264,17 @@ void ConnectionPool::set_ready_to_connect(bool val)
   m_ready_to_connect = val;
 }
 
-void ConnectionPool::set_backend(std::auto_ptr<ConnectionPoolBackend> backend)
+void ConnectionPool::set_backend(std::auto_ptr<Backend> backend)
 {
   m_backend = backend;
 }
 
-ConnectionPoolBackend* ConnectionPool::get_backend()
+ConnectionPool::Backend* ConnectionPool::get_backend()
 {
   return m_backend.get();
 }
 
-const ConnectionPoolBackend* ConnectionPool::get_backend() const
+const ConnectionPool::Backend* ConnectionPool::get_backend() const
 {
   return m_backend.get();
 }
@@ -546,7 +311,7 @@ sharedptr<SharedConnection> ConnectionPool::get_and_connect(std::auto_ptr<Except
 static sharedptr<SharedConnection> connection_cached;
 static sigc::connection connection_cached_timeout_connection;
 
-bool on_connection_pool_cache_timeout()
+static bool on_connection_pool_cache_timeout()
 {
   //std::cout << "DEBUG: Clearing connection cache." << std::endl;
       
@@ -607,9 +372,13 @@ sharedptr<SharedConnection> ConnectionPool::connect(std::auto_ptr<ExceptionConne
       else
       {
         //Allow get_meta_store_data() to succeed:
-        std::cout << "DEBUG: Calling update_meta_store() ..." << std::endl;
-        m_refGdaConnection->update_meta_store();
-        std::cout << "DEBUG: ... update_meta_store() has finished." << std::endl;
+        //Hopefully this (and the update_meta_store_for_table() calls) is all we need.
+        std::cout << "DEBUG: Calling update_meta_store_data_types() ..." << std::endl;
+        m_refGdaConnection->update_meta_store_data_types();
+        std::cout << "DEBUG: ... update_meta_store_data_types() has finished." << std::endl;
+        std::cout << "DEBUG: Calling update_meta_store_table_names() ..." << std::endl;
+        m_refGdaConnection->update_meta_store_table_names();
+        std::cout << "DEBUG: ... update_meta_store_table_names() has finished." << std::endl;
 
         // Connection succeeded
         // Create the fieldtypes member if it has not already been done:
@@ -719,6 +488,12 @@ const FieldTypes* ConnectionPool::get_field_types() const
   return m_pFieldTypes;
 }
 
+Glib::ustring ConnectionPool::get_string_find_operator() const
+{
+  g_assert(m_backend.get());
+  return m_backend->get_string_find_operator();
+}
+
 void ConnectionPool::on_sharedconnection_finished()
 {
   //g_warning("ConnectionPool::on_sharedconnection_finished().");
@@ -875,7 +650,7 @@ void ConnectionPool::cleanup(Gtk::Window* parent_window)
   previous_sig_handler = SIG_DFL; /* Arbitrary default */
 }
 
-#ifndef GLOM_ENABLE_CLIENT_ENLY
+#ifndef GLOM_ENABLE_CLIENT_ONLY
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
 bool ConnectionPool::add_column(const Glib::ustring& table_name, const sharedptr<const Field>& field)
 #else
@@ -1072,7 +847,7 @@ Document_Glom* ConnectionPool::get_document()
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 #ifndef G_OS_WIN32
 //static
-EpcContents* ConnectionPool::on_publisher_document_requested(EpcPublisher* publisher, const gchar* key, gpointer user_data)
+EpcContents* ConnectionPool::on_publisher_document_requested(EpcPublisher* /* publisher */, const gchar* /* key */, gpointer user_data)
 {
   Glom::ConnectionPool* connection_pool = static_cast<Glom::ConnectionPool*>(user_data);
   if(!connection_pool)
@@ -1143,7 +918,7 @@ void ConnectionPool::on_epc_progress_begin(const gchar* /* title */, gpointer us
   connection_pool->m_dialog_epc_progress = message_dialog; 
 }
 
-void ConnectionPool::on_epc_progress_update(gdouble /* progress */, const gchar* /* message */, gpointer user_data)
+void ConnectionPool::on_epc_progress_update(gdouble /* progress */, const gchar* /* message */, gpointer /* user_data */)
 {
   //We ignore the title parameter because there is no way that libepc could know what Glom wants to say.
   //TODO: Show the progress in a ProgressBar.
