@@ -21,13 +21,13 @@
 #ifndef GLOM_CONNECTIONPOOL_H
 #define GLOM_CONNECTIONPOOL_H
 
-#include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
+#include <libglom/libglom_config.h> // For GLOM_ENABLE_CLIENT_ONLY
 
 #include <libgdamm.h>
-#include <glom/libglom/sharedptr.h>
-#include <glom/libglom/data_structure/fieldtypes.h>
-#include <glom/libglom/data_structure/field.h>
-#include <glom/libglom/connectionpool_backends/backend.h>
+#include <libglom/sharedptr.h>
+#include <libglom/data_structure/fieldtypes.h>
+#include <libglom/data_structure/field.h>
+#include <libglom/connectionpool_backends/backend.h>
 
 #include <memory> // For std::auto_ptr
 
@@ -71,7 +71,7 @@ public:
   typedef sigc::signal<void> type_signal_finished;
   type_signal_finished signal_finished();
 
-protected:
+private:
   Glib::RefPtr<Gnome::Gda::Connection> m_gda_connection;
 
   type_signal_finished m_signal_finished;
@@ -84,7 +84,7 @@ class Document_Glom;
  */
 class ConnectionPool : public sigc::trackable
 {
-protected:
+private:
   ConnectionPool();
   //ConnectionPool(const ConnectionPool& src);
   virtual ~ConnectionPool();
@@ -217,7 +217,7 @@ public:
    */
   static bool check_user_is_not_root();
 
-protected:
+private:
   void on_sharedconnection_finished();
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -236,7 +236,7 @@ protected:
 #endif // !G_OS_WIN32
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-protected:
+private:
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   EpcPublisher* m_epc_publisher;
