@@ -29,13 +29,13 @@
 #include <glom/utility_widgets/placeholder-glom.h>
 #include "../application.h"
 #include <gtkmm/checkbutton.h>
-#include <glom/libglom/data_structure/glomconversions.h>
-#include <glom/libglom/glade_utils.h>
+#include <libglom/data_structure/glomconversions.h>
+#include <libglom/glade_utils.h>
 #include "box_data_list_related.h"
 #include "dialog_choose_relationship.h"
 #include <bakery/App/App_Gtk.h> //For util_bold_message().
 #include <glibmm/i18n.h>
-#include <glom/libglom/data_structure/layout/layoutitem_placeholder.h>
+#include <libglom/data_structure/layout/layoutitem_placeholder.h>
 #include <glom/signal_reemitter.h>
 
 namespace Glom
@@ -395,7 +395,7 @@ void FlowTableWithFields::add_layout_notebook_at_position(const sharedptr<Layout
         event_box->set_visible_window(false);
         event_box->signal_button_press_event().connect (sigc::mem_fun (*flow_table,
                                                                        &FlowTableWithFields::on_button_press_event));
-        event_box->show();        
+        event_box->show();
         //This doesn't work (probably because we haven't implmented it in our custom container),
         //so we put the flowtable in an alignment and give that a border instead.
         //flow_table->set_border_width(Glom::Utils::DEFAULT_SPACING_SMALL); //Put some space between the page child and the page edges.
@@ -539,7 +539,7 @@ void FlowTableWithFields::add_field_at_position(const sharedptr<LayoutItem_Field
       label->set_property("yalign", 0.0); //Equivalent to Gtk::ALIGN_TOP. Center is neater next to entries, but center is silly next to large images.
   }
   
-  Gtk::EventBox* eventbox = new Gtk::EventBox();
+  Gtk::EventBox* eventbox = Gtk::manage(new Gtk::EventBox());
   eventbox->add(*info.m_first);
   eventbox->set_visible_window(false);
   eventbox->set_events(Gdk::ALL_EVENTS_MASK);
