@@ -21,7 +21,7 @@
 #ifndef GLOM_PYTHON_H
 #define GLOM_PYTHON_H
 
-#include <glom/libglom/data_structure/field.h>
+#include <libglom/data_structure/field.h>
 #include <glibmm/ustring.h>
 
 namespace Glom
@@ -29,10 +29,10 @@ namespace Glom
 
 typedef std::map<Glib::ustring, Gnome::Gda::Value> type_map_fields;
 
-void glom_execute_python_function_implementation(const Glib::ustring& func_impl, const type_map_fields& field_values, Document_Glom* pDocument, const Glib::ustring& table_name);
+void glom_execute_python_function_implementation(const Glib::ustring& func_impl, const type_map_fields& field_values, Document_Glom* pDocument, const Glib::ustring& table_name, const Glib::RefPtr<Gnome::Gda::Connection>& opened_connection);
 
 Gnome::Gda::Value glom_evaluate_python_function_implementation(Field::glom_field_type result_type, const Glib::ustring& func_impl,
-  const type_map_fields& field_values, Document_Glom* pDocument, const Glib::ustring& table_name);
+  const type_map_fields& field_values, Document_Glom* pDocument, const Glib::ustring& table_name, const Glib::RefPtr<Gnome::Gda::Connection>& opened_connection);
 
 } //namespace Glom
 
