@@ -22,10 +22,13 @@
 #define GLOM_DIALOG_LAYOUT_REPORT
 
 #include "../mode_data/dialog_layout.h"
-#include <glom/libglom/data_structure/report.h>
+#include <libglom/data_structure/report.h>
 #include "treestore_report_layout.h"
-//#include <glom/libglom/data_structure/layout/layoutitem.h>
-//#include <glom/libglom/sharedptr.h>
+//#include <libglom/data_structure/layout/layoutitem.h>
+//#include <libglom/sharedptr.h>
+
+namespace Glom
+{
 
 class Dialog_Layout_Report : public Dialog_Layout
 {
@@ -38,7 +41,7 @@ public:
 
   Glib::ustring get_original_report_name() const;
 
-protected:
+private:
 
   typedef TreeStore_ReportLayout type_model;
 
@@ -120,4 +123,6 @@ protected:
   sharedptr<Report> m_report;
 };
 
+} //namespace Glom
+
 #endif //GLOM_DIALOG_LAYOUT_REPORT
