@@ -18,7 +18,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <glom/libglom/utils.h>
+#include <libglom/utils.h>
 #include "adddel_withbuttons.h"
 //#include <libgnome/gnome-i18n.h>
 
