@@ -21,11 +21,16 @@
 #ifndef GLOM_UTILITY_WIDGETS_COMBO_GLOM_H
 #define GLOM_UTILITY_WIDGETS_COMBO_GLOM_H
 
+#include <libglom/libglom_config.h> // For GLOM_ENABLE_CLIENT_ONLY
+
 #include <gtkmm.h>
-#include "../data_structure/field.h"
+#include <libglom/data_structure/field.h>
 #include "comboglomchoicesbase.h"
 #include <libglademm.h>
 
+namespace Glom
+{
+
 class App_Glom;
 
 class ComboGlom
@@ -58,14 +63,18 @@ public:
 
   virtual Gnome::Gda::Value get_value() const;
 
-protected:
+private:
   void init();
 
+  // Note this is a normal signal handlers when compiled without default
+  // signal handlers
   virtual void on_changed(); //From Gtk::ComboBox
 
   virtual void check_for_change();
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   virtual bool on_button_press_event(GdkEventButton *event);
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   virtual App_Glom* get_application();
 
@@ -74,5 +83,7 @@ protected:
   //Gnome::Gda::Value m_value; //The last-stored value. We have this because the displayed value might be unparseable.
 };
 
+} //namespace Glom
+
 #endif //GLOM_UTILITY_WIDGETS_COMBOENTRY_GLOM_H
 
