@@ -21,10 +21,9 @@
 #include <iostream>
 #include "glom_db_treemodel.h"
 
-#include <glom/libglom/connectionpool.h>
-#include <glom/libglom/connectionpool_backends/sqlite.h> //For checking whether we are using SQLite or not
-#include <glom/libglom/data_structure/glomconversions.h> //For util_build_sql
-#include <glom/libglom/utils.h>
+#include <libglom/connectionpool.h>
+#include <libglom/data_structure/glomconversions.h> //For util_build_sql
+#include <libglom/utils.h>
 
 #include "glom/application.h"
 
@@ -276,8 +275,10 @@ void DbTreeModelRow::fill_values_if_necessary(DbTreeModel& model, int row)
           if(holder)
             m_db_values[i] = holder->get_value(); //TODO_gda: Why not just use get_value_at()?
           else
-            // This is quite possible for example for unset dates, jhs 
-            ;//std::cerr << "DbTreeModelRow::fill_values_if_necessary(): NULL Gnome::Gda::Holder for field=" << i << std::endl;
+          {
+            // This is quite possible, for example for unset dates. jhs 
+            //std::cerr << "DbTreeModelRow::fill_values_if_necessary(): NULL Gnome::Gda::Holder for field=" << i << std::endl;
+          }
 
           //std::cout << "  debug: col=" << i << ", GType=" << m_db_values[i].get_value_type() << ", string=" << m_db_values[i].to_string() << std::endl;
         }
@@ -555,7 +556,7 @@ bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
       m_gda_datamodel.clear(); //So that it is 0, so we can handle it below.
     }
 #endif //GLIBMM_EXCEPTIONS_ENABLED
-      
+
     if(!m_gda_datamodel)
     {
       m_data_model_rows_count = 0;
