@@ -18,23 +18,19 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "config.h" // For GLOM_ENABLE_MAEMO
+#include <libglom/libglom_config.h> // For GLOM_ENABLE_MAEMO
 
 #include "xsl_utils.h"
-#include <glom/libglom/connectionpool.h>
-#include <glom/libglom/data_structure/layout/report_parts/layoutitem_fieldsummary.h>
-#include <glom/libglom/data_structure/glomconversions.h>
+#include <libglom/connectionpool.h>
+#include <libglom/data_structure/layout/report_parts/layoutitem_fieldsummary.h>
+#include <libglom/data_structure/glomconversions.h>
 #include "frame_glom.h"
 #include <libxml++/libxml++.h>
 #include <libxslt/transform.h>
 //#include <libexslt/exslt.h> //For exsltRegisterAll().
-#include <libgnomevfsmm.h>
+#include <giomm.h>
 #include <glibmm/i18n.h>
 
-#ifndef GLOM_ENABLE_MAEMO
-#include <libgnome/gnome-url.h>
-#endif
-
 #include <sstream> //For stringstream
 
 #include <iostream>
@@ -45,6 +41,29 @@
 #include <iostream>   // for cout, endl
 #include <iomanip>
 
+// For ShellExecute:
+#ifdef G_OS_WIN32
+# define GLOM_SAVE_DATADIR DATADIR
+# undef DATADIR
+# include <windows.h>
+# define DATADIR GLOM_SAVE_DATADIR
+#endif
+
+namespace
+{
+	Glib::ustring get_xslt_file(const Glib::ustring& xsl_file)
+	{
+#ifdef G_OS_WIN32
+		gchar* directory;
+		directory = g_win32_get_package_installation_directory_of_module(NULL);
+		Glib::ustring xsltdir = Glib::build_filename(directory, "share/glom/xslt/" + xsl_file);
+		g_free(directory);
+		return xsltdir;
+#else
+		return GLOM_XSLTDIR + xsl_file;
+#endif
+	}
+}
 
 namespace Glom
 {
@@ -52,62 +71,86 @@ namespace Glom
 void GlomXslUtils::transform_and_open(const xmlpp::Document& xml_document, const Glib::ustring& xsl_file_path, Gtk::Window* parent_window)
 {
   //Use libxslt to convert the XML to HTML:
-  Glib::ustring result = xslt_process(xml_document, GLOM_XSLTDIR + xsl_file_path);
+  Glib::ustring result = xslt_process(xml_document, get_xslt_file(xsl_file_path));
   std::cout << "After xslt: " << result << std::endl;
 
   //Save it to a temporary file and show it in a browser:
   //TODO: This actually shows it in gedit.
-  const Glib::ustring temp_uri = "file:///tmp/glom_printout.html";
-  std::cout << "temp_uri=" << temp_uri << std::endl;
+  const Glib::ustring temp_path = Glib::get_tmp_dir() + "/glom_printout.html";
+  std::cout << "temp_path=" << temp_path << std::endl;
 
-  Gnome::Vfs::Handle write_handle;
+  Glib::RefPtr<Gio::File> file = Gio::File::create_for_path(temp_path);
+  Glib::RefPtr<Gio::FileOutputStream> stream;
 
+  //Create the file if it does not already exist:
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
-    //0660 means "this user and his group can read and write this non-executable file".
-    //The 0 prefix means that this is octal.
-    write_handle.create(temp_uri, Gnome::Vfs::OPEN_WRITE, false, 0660 /* leading zero means octal */);
+    if(file->query_exists())
+    {
+      stream = file->replace(); //Instead of append_to().
+    }
+    else
+    {
+      //By default files created are generally readable by everyone, but if we pass FILE_CREATE_PRIVATE in flags the file will be made readable only to the current user, to the level that is supported on the target filesystem.
+      //TODO: Do we want to specify 0660 exactly? (means "this user and his group can read and write this non-executable file".)
+      stream = file->create_file();
+    }
   }
-  catch(const Gnome::Vfs::exception& ex)
+  catch(const Gio::Error& ex)
   {
-    // If the operation was not successful, print the error and abort
-    return; // print_error(ex, output_uri_string);
-  }
 #else
-  std::auto_ptr<Gnome::Vfs::exception> error;
-  write_handle.create(temp_uri, Gnome::Vfs::OPEN_WRITE, false, 0660 /* leading zero means octal */, error);
-  if(error.get()) return;
+  std::auto_ptr<Gio::Error> error;
+  stream.create(error);
+  if(error.get() != NULL)
+  {
+    const Gio::Error& ex = *error.get();
 #endif
+    // If the operation was not successful, print the error and abort
+    return; // false; // print_error(ex, output_uri_string);
+  }
 
+  //Write the data to the output uri
+  gsize bytes_written = 0;
+  const Glib::ustring::size_type result_bytes = result.bytes();
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
-    //Write the data to the output uri
-    /* GnomeVFSFileSize bytes_written = */ write_handle.write(result.data(), result.bytes());
+    bytes_written = stream->write(result.data(), result_bytes);
   }
-  catch(const Gnome::Vfs::exception& ex)
+  catch(const Gio::Error& ex)
   {
-    // If the operation was not successful, print the error and abort
-    return; //print_error(ex, output_uri_string);
-  }
 #else
-  write_handle.create(temp_uri, Gnome::Vfs::OPEN_WRITE, false, 0660 /* leading zero means octal */, error);
-  if(error.get()) return;
+  bytes_written = stream->write(result.data(), result_bytes, error);
+  if(error.get() != NULL)
+  {
+    Gio::Error& ex = *error.get();
 #endif
+    // If the operation was not successful, print the error and abort
+    return; // false; //print_error(ex, output_uri_string);
+  }
+
+  if(bytes_written != result_bytes)
+    return; //false
+
 
   //Give the user a clue, in case the web browser opens in the background, for instance in a new tab:
   if(parent_window)
     Frame_Glom::show_ok_dialog(_("Report Finished"), _("The report will now be opened in your web browser."), *parent_window, Gtk::MESSAGE_INFO);
 
-#ifdef GLOM_ENABLE_MAEMO
-  // TODO_maemo: We don't have libgnome available. A quick search did not yield
-  // a similar method in the hildon API. Perhaps we can just use
-  //  gnome_vfs_url_show()?
+#ifdef G_OS_WIN32
+  // gtk_show_uri doesn't seem to work on Win32, at least not for local files
+  // We use Windows API instead.
+  ShellExecute(NULL, "open", file->get_path().c_str(), NULL, NULL, SW_SHOW);
 #else
   //Use the GNOME browser:
-  GError* gerror = 0; // TODO: This leaks memory if an error occurs. We can pass NULL as error if we are not interested in errors.
-  gnome_url_show(temp_uri.c_str(), &gerror); //This is in libgnome.
+  //TODO: Use gtk_show_uri() as soon as we require GTK+ 2.14
+  GError* gerror = 0;
+  if(!g_app_info_launch_default_for_uri(file->get_uri().c_str(), NULL, &gerror))
+  {
+    std::cerr << "Error while calling g_app_info_launch_default_for_uri(): " << gerror->message << std::endl;
+    g_error_free(gerror);
+  }
 #endif
 }
 
